var chai = require('chai');
var expect = chai.expect;
var chaiHttp = require('chai-http');

var responseEntity = require('../utility/ResponseEntity.js');

chai.use(chaiHttp);

/*
** Test cases for Sequelize error
*/
describe('Check for Seqelize error', function () {
    it('Should return a Sequelize database error ', function (done) {
        var error = {
            "name": "SequelizeDatabaseError",
            "message": "database error"
        }

        responseEntity.sendResponse("US", null, null, error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-1001');
            done();
        })
    });

    it('Should return a Sequelize validation error ', function (done) {
        var error = {
            "name": "SequelizeValidationError",
            "message": "Invalid input paramters"
        }

        responseEntity.sendResponse("US", null, null, error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-1002');
            done();
        })
    });

    it('Should return a generic database error', function (done) {

        var error = {
            "name": "SequelizeError",
            "message": "connection close"
        }

        responseEntity.sendResponse("US", null, null, error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-3001');
            done();
        })
    });
});

/*
** Test cases for cassandra database errors
*/
describe('Check for cassandra error', function () {
    it('Should return a cassandra validation error', function (done) {
        var error = {
            "name": "apollo.model.validator.invalidvalue",
            "message": "validation error"
        }

        responseEntity.sendResponse("PS", null, null, error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-2002');
            done();
        })
    });

    it('Should return a generlize database error', function (done) {
        var error = {
            "name": "CassandraError",
            "message": "connection close"
        }

        responseEntity.sendResponse("PS", null, null, error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-3001');
            done();
        })
    });
});

/*
** Test cases for Input validation errors
*/
describe('Check for input validation error', function () {
    it('Should return an error', function (done) {
        responseEntity.sendResponse("PS", 422, null, null, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-422');
            done();
        })
    });
});

/*
** Test cases for success response
*/
describe('Check for success response object', function () {
    it('Should return a successfully created response ', function (done) {
        var data = {
            "id": 13
        }
        responseEntity.sendResponse("US", 201, data, null, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-201');
            done();
        })
    });

    it('Should return a success response ', function (done) {
        var data = {'id': '13','name': 'shiwani','mobNo': '9876543212'};
        responseEntity.sendResponse("US", 200, data, null, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-200');
            done();
        })
    });
});