'use strict';

var constants = require('../constants');
var errObj = require('../config/ErrorObject');

var store = {};

store.sendResponse = function (module_name, code, data, error, callback) {
  var response = {};

  if (code == null || code == undefined) {
    if (error.name == 'SequelizeDatabaseError')
      code = constants.SEQUELIZE_DATABASE_ERROR;
    else if (error.name == 'SequelizeValidationError')
      code = constants.SEQUELIZE_VALIDATION_ERROR;
    else if (error.name == 'apollo.model.validator.invalidvalue')
      code = constants.CASSANDRA_VALIDATION_ERROR;
    else
      code = constants.UNDEFINED_DATABASE_ERROR
  }
  
  response.code = module_name + '-' + code;
  response.message = getResponse(code);

  if (error != null) response.error = error;

  if (data != null) {
    var isValidFlag = isValidJson(data);    
    if (isValidFlag) {
      if (!data.hasOwnProperty('rows')) {
        response.data = data;
      }
      else {
        response.count = data.count;
        response.data = data.rows;
      }
    }
    else {
      code = constants.INVALID_JSON_OBJECT;
      response.message = getResponse(code);
      response.code = module_name + '-' + code;
    }
  }

  callback(response);
}

var getResponse = function (code) {
  return errObj[code];
};

var isValidJson = function (jsonObj) {
  var isValidJsonObj = false;
  try {
    JSON.parse(JSON.stringify(jsonObj));        
    isValidJsonObj = true;
  } catch (e) {
    console.log(e);
    isValidJsonObj = false;
  }
  return isValidJsonObj;
}

module.exports = store;